@@ -4,8 +4,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_DATA_SOURCE_INTERFACE_H
-#define WAYLAND_SERVER_DATA_SOURCE_INTERFACE_H
+#pragma once
 
 #include "abstract_data_source.h"
 
@@ -20,7 +19,7 @@ class DataSourceInterfacePrivate;
 
 /**
  * @brief Represents the Resource for the wl_data_source interface.
- **/
+ */
 class KWAYLANDSERVER_EXPORT DataSourceInterface : public AbstractDataSource
 {
     Q_OBJECT
@@ -37,8 +36,7 @@ public:
 
     /**
      * @returns The Drag and Drop actions supported by this DataSourceInterface.
-     * @since 5.42
-     **/
+     */
     DataDeviceManagerInterface::DnDActions supportedDragAndDropActions() const override;
 
     void dropPerformed() override;
@@ -62,5 +60,3 @@ private:
 }
 
 Q_DECLARE_METATYPE(KWaylandServer::DataSourceInterface*)
-
-#endif
