@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_DPMS_INTERFACE_P_H
-#define WAYLAND_SERVER_DPMS_INTERFACE_P_H
+#pragma once
 
 #include "dpms_interface.h"
 
@@ -47,5 +46,3 @@ protected:
 };
 
 }
-
-#endif
