@@ -3,22 +3,20 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef KWAYLAND_SERVER_OUTPUTCHANGESET_P_H
-#define KWAYLAND_SERVER_OUTPUTCHANGESET_P_H
+#pragma once
 
 #include "outputchangeset.h"
 
 namespace KWaylandServer
 {
 
-class OutputChangeSet::Private
+class OutputChangeSetPrivate
 {
 public:
-    Private(OutputDeviceInterface *outputdevice, OutputChangeSet *parent);
-    ~Private();
+    OutputChangeSetPrivate(OutputDeviceInterface *outputdevice, OutputChangeSet *parent);
 
     OutputChangeSet *q;
-    OutputDeviceInterface *o;
+    OutputDeviceInterface *outputDevice;
 
     OutputDeviceInterface::Enablement enabled;
     int modeId;
@@ -26,8 +24,8 @@ public:
     QPoint position;
     qreal scale;
     OutputDeviceInterface::ColorCurves colorCurves;
+    uint32_t overscan;
+    OutputDeviceInterface::VrrPolicy vrrPolicy = OutputDeviceInterface::VrrPolicy::Automatic;
 };
 
 }
-
-#endif
