@@ -4,8 +4,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_SURFACE_INTERFACE_H
-#define WAYLAND_SERVER_SURFACE_INTERFACE_H
+#pragma once
 
 #include "output_interface.h"
 
@@ -53,21 +52,21 @@ class SurfaceInterfacePrivate;
  * @see ContrastInterface
  * @see ShadowInterface
  * @see SlideInterface
- **/
+ */
 class KWAYLANDSERVER_EXPORT SurfaceInterface : public QObject
 {
     Q_OBJECT
     /**
      * The current damage region.
-     **/
+     */
     Q_PROPERTY(QRegion damage READ damage NOTIFY damaged)
     /**
      * The opaque region for a translucent buffer.
-     **/
+     */
     Q_PROPERTY(QRegion opaque READ opaque NOTIFY opaqueChanged)
     /**
      * The current input region.
-     **/
+     */
     Q_PROPERTY(QRegion input READ input NOTIFY inputChanged)
     Q_PROPERTY(qint32 bufferScale READ bufferScale NOTIFY bufferScaleChanged)
     Q_PROPERTY(KWaylandServer::OutputInterface::Transform bufferTransform READ bufferTransform NOTIFY bufferTransformChanged)
@@ -108,7 +107,6 @@ public:
      * The returned value will become invalid when the surfaceToBufferMatrixChanged() signal is emitted.
      *
      * @see surfaceToBufferMatrix(), surfaceToBufferMatrixChanged()
-     * @since 5.20
      */
     QPointF mapToBuffer(const QPointF &point) const;
     /**
@@ -121,7 +119,6 @@ public:
      * The returned value will become invalid when the surfaceToBufferMatrixChanged() signal is emitted.
      *
      * @see surfaceToBufferMatrix(), surfaceToBufferMatrixChanged()
-     * @since 5.20
      */
     QPointF mapFromBuffer(const QPointF &point) const;
     /**
@@ -134,7 +131,6 @@ public:
      * The returned value will become invalid when the surfaceToBufferMatrixChanged() signal is emitted.
      *
      * @see surfaceToBufferMatrix(), surfaceToBufferMatrixChanged()
-     * @since 5.20
      */
     QRegion mapToBuffer(const QRegion &region) const;
     /**
@@ -147,17 +143,23 @@ public:
      * The returned value will become invalid when the surfaceToBufferMatrixChanged() signal is emitted.
      *
      * @see surfaceToBufferMatrix(), surfaceToBufferMatrixChanged()
-     * @since 5.20
      */
     QRegion mapFromBuffer(const QRegion &region) const;
     /**
      * Returns the projection matrix from the surface-local coordinates to buffer coordinates.
      *
      * @see surfaceToBufferMatrixChanged()
-     * @since 5.20
      */
     QMatrix4x4 surfaceToBufferMatrix() const;
 
+    /**
+     * Maps the specified @a point in this surface's coordinate system to the equivalent point
+     * within the @a child's coordinate system, and returns the mapped point.
+     *
+     * If this surface is not an ancestor of the @a child, a null point is returned.
+     */
+    QPointF mapToChild(SurfaceInterface *child, const QPointF &point) const;
+
     void frameRendered(quint32 msec);
     bool hasFrameCallbacks() const;
 
@@ -175,7 +177,7 @@ public:
     OutputInterface::Transform bufferTransform() const;
     /**
      * @returns the current BufferInterface, might be @c nullptr.
-     **/
+     */
     BufferInterface *buffer();
     QPoint offset() const;
     /**
@@ -189,8 +191,6 @@ public:
      * Returns the rectangle that bounds this surface and all of its sub-surfaces.
      *
      * QPoint(0, 0) corresponds to the upper left corner of this surface.
-     *
-     * @since 5.69
      */
     QRect boundingRect() const;
     /**
@@ -202,35 +202,31 @@ public:
 
     /**
      * @returns The SubSurface for this Surface in case there is one.
-     **/
+     */
     SubSurfaceInterface *subSurface() const;
     /**
      * @returns Children in stacking order from bottom (first) to top (last).
-     **/
+     */
     QList<SubSurfaceInterface *> childSubSurfaces() const;
 
     /**
      * @returns The Shadow for this Surface.
-     * @since 5.4
-     **/
+     */
     QPointer<ShadowInterface> shadow() const;
 
     /**
      * @returns The Blur for this Surface.
-     * @since 5.5
-     **/
+     */
     QPointer<BlurInterface> blur() const;
 
     /**
      * @returns The Slide for this Surface.
-     * @since 5.5
-     **/
+     */
     QPointer<SlideInterface> slideOnShowHide() const;
 
     /**
      * @returns The Contrast for this Surface.
-     * @since 5.5
-     **/
+     */
     QPointer<ContrastInterface> contrast() const;
 
     /**
@@ -240,38 +236,9 @@ public:
      * mapped if it has a BufferInterface attached and the parent SurfaceInterface is mapped.
      *
      * @returns Whether the SurfaceInterface is currently mapped
-     * @since 5.22
-     **/
+     */
     bool isMapped() const;
 
-    /**
-     * Returns the tracked damage since the last call to  {@link resetTrackedDamage}.
-     * In contrast to {@link damage} this method does not reset the damage when
-     * a new BufferInterface gets committed. This allows a compositor to properly
-     * track the damage over multiple commits even if it didn't render each new
-     * BufferInterface.
-     *
-     * The damage gets reset whenever {@link resetTrackedDamage} is called.
-     * This allows a compositor to properly track the change in its rendering scene
-     * for this SurfaceInterface. After it updates its internal state (e.g. by creating
-     * an OpenGL texture from the BufferInterface) it can invoke {@link resetTrackedDamage}
-     * and the damage tracker will start to track further damage changes.
-     *
-     * @returns Combined damage since last call to resetTrackedDamage
-     * @see damage
-     * @see resetTrackedDamage
-     * @since 5.22
-     **/
-    QRegion trackedDamage() const;
-
-    /**
-     * Reset the damage tracking. The compositor should invoke this method once it updated
-     * it's internal state and processed the current damage.
-     * @see trackedDamage
-     * @since 5.22
-     **/
-    void resetTrackedDamage();
-
     /**
      * Finds the SurfaceInterface at the given @p position in surface-local coordinates.
      * This can be either a descendant SurfaceInterface honoring the stacking order or
@@ -282,8 +249,7 @@ public:
      *
      * @param position The position in surface-local coordinates
      * @returns Child surface at the given @p position or surface itself at the position, might be @c nullptr
-     * @since 5.22
-     **/
+     */
     SurfaceInterface *surfaceAt(const QPointF &position);
 
     /**
@@ -297,8 +263,7 @@ public:
      *
      * @param position The position in surface-local coordinates
      * @returns Input receiving child surface at the given @p position or surface itself at the position, might be @c nullptr
-     * @since 5.52
-     **/
+     */
     SurfaceInterface *inputSurfaceAt(const QPointF &position);
 
     /**
@@ -308,46 +273,40 @@ public:
      * an OutputInterface by e.g. getting (un)mapped, resized, moved, etc.
      *
      * @see outputs
-     * @since 5.27
-     **/
+     */
     void setOutputs(const QVector<OutputInterface *> &outputs);
 
     /**
      * @returns All OutputInterfaces the SurfaceInterface is on.
      * @see setOutputs
-     * @since 5.27
-     **/
+     */
     QVector<OutputInterface *> outputs() const;
 
     /**
      * Pointer confinement installed on this SurfaceInterface.
      * @see pointerConstraintsChanged
-     * @since 5.29
-     **/
+     */
     ConfinedPointerV1Interface *confinedPointer() const;
 
     /**
      * Pointer lock installed on this SurfaceInterface.
      * @see pointerConstraintsChanged
-     * @since 5.29
-     **/
+     */
     LockedPointerV1Interface *lockedPointer() const;
 
     /**
      * @returns Whether this SurfaceInterface wants idle to be inhibited on the Output it is shown
      * @see inhibitsIdleChanged
-     * @since 5.41
-     **/
+     */
     bool inhibitsIdle() const;
 
     /**
      * @returns The SurfaceInterface for the @p native resource.
-     **/
+     */
     static SurfaceInterface *get(wl_resource *native);
     /**
      * @returns The SurfaceInterface with given @p id for @p client, if it exists, otherwise @c nullptr.
-     * @since 5.3
-     **/
+     */
     static SurfaceInterface *get(quint32 id, const ClientConnection *client);
 
     /**
@@ -356,14 +315,12 @@ public:
      *
      * Setting a data proxy is only allowed when the client owning this surface
      * has not created a data device itself.
-     * @since 5.56
-     **/
+     */
     void setDataProxy(SurfaceInterface *surface);
     /**
      * Returns the data proxy of this SurfaceInterface or null if there
      * is none set.
-     * @since 5.56
-     **/
+     */
     SurfaceInterface* dataProxy() const;
 
 Q_SIGNALS:
@@ -392,7 +349,7 @@ Q_SIGNALS:
      *
      * @see buffer
      * @see damage
-     **/
+     */
     void damaged(const QRegion&);
     void opaqueChanged(const QRegion&);
     void inputChanged(const QRegion&);
@@ -410,47 +367,32 @@ Q_SIGNALS:
     void bufferSizeChanged();
     /**
      * Emitted when the Surface becomes visible, i.e. a non-null buffer has been attached.
-     **/
+     */
     void mapped();
     /**
      * Emitted when the Surface removes its content
-     **/
+     */
     void unmapped();
     /**
      * This signal is emitted when the surface size has changed.
      */
     void sizeChanged();
-    /**
-     * @since 5.4
-     **/
     void shadowChanged();
-    /**
-     * @since 5.5
-     **/
     void blurChanged();
-    /**
-     * @since 5.5
-     **/
     void slideOnShowHideChanged();
-    /**
-     * @since 5.5
-     **/
     void contrastChanged();
-    /**
-     * Emitted whenever the tree of sub-surfaces changes in a way which requires a repaint.
-     * @since 5.22
-     **/
-    void subSurfaceTreeChanged();
     /**
      * Emitted whenever a new child sub-surface @p subSurface is added.
-     * @since 5.70
      */
     void childSubSurfaceAdded(SubSurfaceInterface *subSurface);
     /**
      * Emitted whenver the child sub-surface @p subSurface is removed.
-     * @since 5.70
      */
     void childSubSurfaceRemoved(SubSurfaceInterface *subSurface);
+    /**
+     * This signal is emitted when the list of child subsurfaces changes.
+     */
+    void childSubSurfacesChanged();
 
     /**
      * Emitted whenever a pointer constraint get (un)installed on this SurfaceInterface.
@@ -460,15 +402,13 @@ Q_SIGNALS:
      *
      * @see confinedPointer
      * @see lockedPointer
-     * @since 5.29
-     **/
+     */
     void pointerConstraintsChanged();
 
     /**
      * Emitted whenever the SurfaceInterface starts/ends to inhibit idle.
      * @see inhibitsIdle
-     * @since 5.41
-     **/
+     */
     void inhibitsIdleChanged();
 
     /**
@@ -476,8 +416,7 @@ Q_SIGNALS:
      *
      * This signal is emitted after all the relevant damage and xyzChanged signals
      * for this commit are emitted.
-     * @since 5.54
-     **/
+     */
     void committed();
 
 private:
@@ -490,5 +429,3 @@ private:
 }
 
 Q_DECLARE_METATYPE(KWaylandServer::SurfaceInterface*)
-
-#endif
